@@ -10,7 +10,8 @@ type param interface {
 	length() int
 }
 
-var errParamTypeUnhandled = errors.New("unhandled ParamType")
+// ErrParamTypeUnhandled is returned if unknown parameter type is specified.
+var ErrParamTypeUnhandled = errors.New("unhandled ParamType")
 
 func buildParam(t paramType, rawParam []byte) (param, error) {
 	switch t {
@@ -35,6 +36,6 @@ func buildParam(t paramType, rawParam []byte) (param, error) {
 	case reconfigResp:
 		return (&paramReconfigResponse{}).unmarshal(rawParam)
 	default:
-		return nil, fmt.Errorf("%w: %v", errParamTypeUnhandled, t)
+		return nil, fmt.Errorf("%w: %v", ErrParamTypeUnhandled, t)
 	}
 }
